@@ -49,6 +49,9 @@ class AirTouch:
         self.UpdateInfo();
 
     def UpdateInfo(self):
+        #if we are trying to call this again, clear out the errors from last time - we want to still
+        #be able to keep going if theres a hiccup such as a bad network connection
+        delattr(self, "error");
         self.acs = dict();
         self.groups = dict();
         #get the group infos
@@ -222,6 +225,7 @@ class AirTouch:
 
     def TranslatePacketToMessage(self, dataResult):
 
+        #If the request hasn't gone well, we don't want to update any of the data we have with bad/no data
         if(isinstance(dataResult, Exception)):
             self.error = dataResult;
             return;
